@@ -7,7 +7,7 @@ class User(mongo.Document):
     MAX_PASSWORD_LENGTH = 64
     USER_EMAIL_REGEX = "^[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*$"
     
-    username = mongo.StringField(unique=True, min_length=MIN_USERNAME_LENGTH, max_length=MAX_USERNAME_LENGTH)
+    name = mongo.StringField(min_length=MIN_USERNAME_LENGTH, max_length=MAX_USERNAME_LENGTH)
     password = mongo.BinaryField(required=True)
     email = mongo.StringField(unique=True, regex=USER_EMAIL_REGEX)
 
